package com.zanxiang.manage.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zanxiang.common.enums.PayDeviceEnum;
import com.zanxiang.common.enums.PayWayEnum;
import com.zanxiang.common.utils.bean.BeanUtils;
import com.zanxiang.manage.domain.params.PayMerchantListParam;
import com.zanxiang.manage.domain.vo.PayMerchantChoiceVO;
import com.zanxiang.manage.domain.vo.PayMerchantListVO;
import com.zanxiang.manage.service.IPayMerchantService;
import com.zanxiang.manage.service.IPayWayService;
import com.zanxiang.mybatis.entity.PayMerchant;
import com.zanxiang.mybatis.mapper.PayMerchantMapper;
import org.apache.logging.log4j.util.Strings;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/**
 * 游戏支付商户配置表 服务实现类
 *
 * @author xufeng
 * @date 2022-06-16 19:04
 */
@Service
public class PayMerchantServiceImpl extends ServiceImpl<PayMerchantMapper, PayMerchant> implements IPayMerchantService {

    @Autowired
    private IPayWayService payWayService;

    @Override
    public List<PayMerchantChoiceVO> payMerchantChoiceList() {
        List<PayMerchant> payMerchantList = super.list(new LambdaQueryWrapper<PayMerchant>().
                select(PayMerchant::getMerchantNo, PayMerchant::getMerchantName));
        return BeanUtils.copyList(payMerchantList, PayMerchantChoiceVO.class);
    }

    @Override
    public IPage<PayMerchantListVO> pageList(PayMerchantListParam param) {
        return page(param.toPage(), new LambdaQueryWrapper<PayMerchant>()
                .eq(param.getMerchantNo() != null, PayMerchant::getMerchantNo, param.getMerchantNo())
                .eq(param.getPayWayId() != null, PayMerchant::getPayWayId, param.getPayWayId())
                .eq(param.getStatus() != null, PayMerchant::getStatus, param.getStatus())
                .like(Strings.isNotBlank(param.getMerchantName()), PayMerchant::getMerchantName, param.getMerchantName())
                .orderByDesc(PayMerchant::getCreateTime))
                .convert(this::toVo);
    }

    private PayMerchantListVO toVo(PayMerchant payMerchant) {
        PayMerchantListVO payMerchantListVO = BeanUtils.copy(payMerchant, PayMerchantListVO.class);
        if (payMerchantListVO == null) {
            return null;
        }
        List<String> payDeviceNameList = new ArrayList<>();
        if (Objects.equals(payMerchant.getPayWayId().intValue(), PayWayEnum.ALI_PAY.getPayWayId())) {
            payDeviceNameList.add(PayDeviceEnum.PC_PAY.getPayDeviceName());
            payDeviceNameList.add(PayDeviceEnum.H5_PAY.getPayDeviceName());
            payDeviceNameList.add(PayDeviceEnum.APP_PAY.getPayDeviceName());
        }
        if (Objects.equals(payMerchant.getPayWayId().intValue(), PayWayEnum.WX_PAY.getPayWayId())) {
            payDeviceNameList.add(PayDeviceEnum.PC_PAY.getPayDeviceName());
            payDeviceNameList.add(PayDeviceEnum.H5_PAY.getPayDeviceName());
            payDeviceNameList.add(PayDeviceEnum.APPLET_PAY.getPayDeviceName());
            payDeviceNameList.add(PayDeviceEnum.MI_PAY.getPayDeviceName());
            payDeviceNameList.add(PayDeviceEnum.CUSTOM_PAY.getPayDeviceName());
        }
        payMerchantListVO.setPayDeviceNameList(payDeviceNameList);
        return payMerchantListVO;
    }


}
